.. _tutorial:

Tutorials
========================

This section of the Spyctl documentation contains the tutorials. A tutorial
shows how to accomplish a goal that is larger than a single task. Typically a
tutorial has several sections, each of which has a sequence of steps.

Basics
-------
.. toctree::
   :maxdepth: 1

   spyctl_basics
   policy_management
